@@ -151,8 +151,8 @@ static boolean parse_quit          PARAMS((const struct parser_table*, char *arg
 
 
 boolean parse_print             PARAMS((const struct parser_table*, char *argv[], int *arg_ptr));
-boolean parse_open              PARAMS((const struct parser_table* entry, char *argv[], int *arg_ptr));
-boolean parse_close             PARAMS((const struct parser_table* entry, char *argv[], int *arg_ptr));
+boolean parse_openparen              PARAMS((const struct parser_table* entry, char *argv[], int *arg_ptr));
+boolean parse_closeparen             PARAMS((const struct parser_table* entry, char *argv[], int *arg_ptr));
 
 
 
@@ -206,8 +206,8 @@ static struct parser_table const parse_table[] =
 {
   PARSE_PUNCTUATION("!",                     negate),
   PARSE_PUNCTUATION("not",                   negate),	     /* GNU */
-  PARSE_PUNCTUATION("(",                     open),
-  PARSE_PUNCTUATION(")",                     close),
+  PARSE_PUNCTUATION("(",                     openparen),
+  PARSE_PUNCTUATION(")",                     closeparen),
   PARSE_PUNCTUATION(",",                     comma),	     /* GNU */
   PARSE_PUNCTUATION("a",                     and),
   PARSE_TEST       ("amin",                  amin),	     /* GNU */
@@ -474,7 +474,7 @@ parse_atime (const struct parser_table* entry, char **argv, int *arg_ptr)
 }
 
 boolean
-parse_close (const struct parser_table* entry, char **argv, int *arg_ptr)
+parse_closeparen (const struct parser_table* entry, char **argv, int *arg_ptr)
 {
   struct predicate *our_pred;
 
@@ -482,9 +482,9 @@ parse_close (const struct parser_table* entry, char **argv, int *arg_ptr)
   (void) arg_ptr;
   
   our_pred = get_new_pred (entry);
-  our_pred->pred_func = pred_close;
+  our_pred->pred_func = pred_closeparen;
 #ifdef	DEBUG
-  our_pred->p_name = find_pred_name (pred_close);
+  our_pred->p_name = find_pred_name (pred_closeparen);
 #endif	/* DEBUG */
   our_pred->p_type = CLOSE_PAREN;
   our_pred->p_prec = NO_PREC;
@@ -1208,7 +1208,7 @@ parse_okdir (const struct parser_table* entry, char **argv, int *arg_ptr)
 }
 
 boolean
-parse_open (const struct parser_table* entry, char **argv, int *arg_ptr)
+parse_openparen (const struct parser_table* entry, char **argv, int *arg_ptr)
 {
   struct predicate *our_pred;
 
@@ -1216,9 +1216,9 @@ parse_open (const struct parser_table* entry, char **argv, int *arg_ptr)
   (void) arg_ptr;
   
   our_pred = get_new_pred_chk_op (entry);
-  our_pred->pred_func = pred_open;
+  our_pred->pred_func = pred_openparen;
 #ifdef	DEBUG
-  our_pred->p_name = find_pred_name (pred_open);
+  our_pred->p_name = find_pred_name (pred_openparen);
 #endif	/* DEBUG */
   our_pred->p_type = OPEN_PAREN;
   our_pred->p_prec = NO_PREC;
