@@ -32,9 +32,10 @@
 # include <sys/types.h>
 #endif
 
-#if HAVE_UNISTD_H
-# include <unistd.h>
-#endif
+/* The presence of unistd.h is assumed by gnulib these days, so we 
+ * might as well assume it too. 
+ */
+#include <unistd.h>
 
 #include <errno.h>
 
@@ -168,7 +169,6 @@ xsavedir(const char *dir, int flags)
   struct dirent *dp;
   struct savedir_dirinfo *result = NULL;
   struct new_savedir_direntry_internal *internal;
-  struct savedir_direntry *external;
   
   size_t namebuf_allocated = 0u, namebuf_used = 0u;
   size_t entrybuf_allocated = 0u;
@@ -293,9 +293,14 @@ new_savedirinfo (const char *dir, struct savedir_extrainfo **extra)
 	free (pex);
       return buf;
     }
+  else
+    {
+      return NULL;
+    }
 }
 
 
+#if 0
 /* Return a freshly allocated string containing the filenames
    in directory DIR, separated by '\0' characters;
    the end is marked by two '\0' characters in a row.
@@ -371,6 +376,7 @@ old_savedirinfo (const char *dir, struct savedir_extrainfo **extra)
   
   return name_space;
 }
+#endif
 
 
 char *
